@@ -9,9 +9,10 @@ from firebase_admin import db
 
 def  extractFromFirebase(certificate_json_file_path,firebase_url):
     cred = credentials.Certificate(certificate_json_file_path)
-    firebase_admin.initialize_app(cred,{'databaseURL':firebase_url})
+    app=firebase_admin.initialize_app(cred,{'databaseURL':firebase_url})
     ref=db.reference()
     mydict=ref.get()
+    delete_app(app)
     return mydict
 
 
